DropTable class

Drop table from DB if it exists

Inheritance

Constructors

DropTable(String name)
const

Properties

down → MigrationCommand
Outputs the opposite command to be used in a generator
no setteroverride
forGenerator → String
Outputs model as String to be used in a generator
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statement → String
Outputs statement to be interpreted by SQLite
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Alias for statement
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited