MigrationManager class

Holds all migrations and outputs statements for SQLite to consume

Constructors

MigrationManager(Set<Migration> migrations)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
migrationByVersion → Map<int, Migration>
Key/value migrations based on their version
no setter
migrations → Set<Migration>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → int
Identifies the latest migrations, especially those not yet added to the Schema The delta between Schema's version and MigrationManager's are unprocessed migrations
no setter

Methods

migrationAt(int versionNumber) → Migration?
Migration at a version
migrationsSince([int? versionNumber]) → List<Migration>
Migrations after a version
migrationsUntil([int? versionNumber]) → Map<int, Migration>
Migrations before and including a version
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

latestMigrationVersion(Iterable<Migration> _migrations) → int
Sort migrations by their version number in ascending order and return the latest Migration version or 0 if _migrations is empty