Schema class

Constructors

Schema(int version, {required Set<SchemaTable> tables, int generatorVersion = GENERATOR_VERSION})
Schema.fromMigrations(Set<Migration> migrations, [int? version])
Create a schema from a set of migrations. If version is not provided, the highest migration version will be used
factory

Properties

forGenerator → String
Output for generator
no setter
generatorVersion → int
Version used to produce this scheme
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tables → Set<SchemaTable>
final
version → int
The last version successfully migrated to SQLite. This should be before or equal to MigrationManager's #version. if MigrationManager is used.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

expandMigrations(Set<Migration> migrations) → List<MigrationCommand>

Constants

GENERATOR_VERSION → const int